.. _util:

Utilities
=========

URI Functions
-------------

.. automodule:: falcon.util.uri
    :members:

Testing
-------

.. autoclass:: falcon.testing.TestBase
    :members:

.. autoclass:: falcon.testing.TestResource
    :members:

.. autoclass:: falcon.testing.StartResponseMock
    :members:

.. automodule:: falcon.testing
    :members: rand_string, create_environ

Miscellaneous
-------------

.. automodule:: falcon
    :members: deprecated, http_now, dt_to_http, http_date_to_dt, to_query_str

.. autoclass:: falcon.util.TimezoneGMT
    :members:
